local Class = require 'lib.hump.class'

local DEFAULT_SPEED = 200
local BOOST_SPEED = DEFAULT_SPEED * 3
local DEFAULT_TURN_SPEED = math.pi * 0.03
local BOOST_TURN_SPEED = DEFAULT_TURN_SPEED * 0.2

local Player = Class{}

function Player:resetSpeed()
	self.speed = 0
	self.turnSpeed = DEFAULT_TURN_SPEED
end

function Player:init(collider)
	self.x = 400
	self.y = 300
	self.shape = collider:addRectangle(self.x, self.y, 32, 32)
	self.speed = 0
	self.angle = 0
	self.turnSpeed = DEFAULT_TURN_SPEED
	self.sprite = love.graphics.newImage('gfx/snowblower.png')
end

function Player:update(dt)
	if love.keyboard.isDown('up') and love.keyboard.isDown(' ') then
		self.speed = BOOST_SPEED
		self.turnSpeed = BOOST_TURN_SPEED
	elseif love.keyboard.isDown('up') then
		self.speed = DEFAULT_SPEED
		self.turnSpeed = DEFAULT_TURN_SPEED
	else 
		self:resetSpeed()
	end

	if love.keyboard.isDown('left') then
		self.angle = self.angle - self.turnSpeed
		self.shape:rotate(-self.turnSpeed)
	elseif love.keyboard.isDown('right') then
		self.angle = self.angle + self.turnSpeed
		self.shape:rotate(self.turnSpeed)
	end

	local dx = math.cos(self.angle) * self.speed * dt
	local dy = math.sin(self.angle) * self.speed * dt
	self.shape:move(dx, dy)
end

function Player:draw()
	local x,y = self.shape:center()
	local imageOffset = 16
	love.graphics.draw(self.sprite, x, y, self.angle, 1, 1, imageOffset, imageOffset)
end

return Player